@@ -5,21 +5,9 @@ from fundamentals import utKit
 
 # OVERRIDES
 
-
 class utKit(utKit):
-
     """
     *Override dryx utKit*
-
-    .. todo ::
-
-        - update key arguments values and definitions with defaults
-        - update return values and definitions
-        - update usage examples and text
-        - update docstring text
-        - check sublime snippet exists
-        - clip any useful text to docs mindmap
-        - regenerate the docs and check redendering of this docstring
     """
     # Variable Data Atrributes
 
@@ -27,7 +15,8 @@ class utKit(utKit):
     # Initialisation
     def __init__(
             self,
-            moduleDirectory
+            moduleDirectory,
+            dbConn=False
     ):
         self.moduleDirectory = moduleDirectory
         # x-self-arg-tmpx
@@ -56,17 +45,57 @@ class utKit(utKit):
                 formatter: console_style
                 stream: ext://sys.stdout
         root:
-            level: WARNING
+            level: DEBUG
             handlers: [console]"""
 
         # Override Variable Data Atrributes
-        self.dbConfig = """
-         version: 1
-         db: unit_tests
-         host: localhost
-         user: utuser
-         password: utpass
-         loginPath: unittesting
-         """
+        self.dbConfig = False
+        if dbConn:
+            self.dbConfig = """
+             version: 1
+             db: dryx_unit_testing
+             host: localhost
+             user: unittesting
+             password: utpass
+             """
 
         return
+
+    def get_project_root(self):
+        """
+        *Get the root of the `python` package - useful for getting files in the root directory of a project*
+
+        **Return**
+
+        - ``rootPath`` -- the root path of a project
+        
+        """
+        import os
+        rootPath = os.path.dirname(__file__)
+
+        return rootPath
+
+    def refresh_database(self):
+        """
+        *Refresh the unit test database*
+        """
+        from fundamentals.mysql import directory_script_runner
+        from fundamentals import tools
+        packageDirectory = self.get_project_root()
+        su = tools(
+            arguments={"settingsFile": packageDirectory +
+                       "/test_settings.yaml"},
+            docString=__doc__,
+            logLevel="DEBUG",
+            options_first=False,
+            projectName=None,
+            defaultSettingsFile=False
+        )
+        arguments, settings, log, dbConn = su.setup()
+        directory_script_runner(
+            log=log,
+            pathToScriptDirectory=packageDirectory + "/tests/input",
+            dbConn=dbConn,
+            successRule=None,
+            failureRule=None
+        )
